@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.67.2.2 2008/10/01 10:02:39 joern Exp $
+# $Id: Config.pm,v 1.67.2.3 2009-02-22 18:49:03 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2006 Jrn Reder <joern AT zyn.de>.
@@ -10,6 +10,7 @@
 
 package Video::DVDRip::Config;
 use Locale::TextDomain qw (video.dvdrip);
+use POSIX qw(locale_h);
 
 use base Video::DVDRip::Base;
 
@@ -253,7 +254,7 @@ my %CONFIG_PARAMETER = (
         label => __ "OGG file extension",
         type  => 'string',
         value => 'ogm',
-        presets => [ 'ogg', 'ogm', ],
+        presets => [ 'ogg', 'ogm', 'ogv' ],
     },
     cluster_master_local => {
         label => __ "Start cluster control daemon locally",
@@ -759,7 +760,7 @@ sub save {
     my $fh = FileHandle->new;
 
     open( $fh, "> $filename" ) or die "can't write $filename";
-    print $fh q{# $Id: Config.pm,v 1.67.2.2 2008/10/01 10:02:39 joern Exp $},
+    print $fh q{# $Id: Config.pm,v 1.67.2.3 2009-02-22 18:49:03 joern Exp $},
         "\n";
     print $fh
         "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
