@@ -1,4 +1,4 @@
-# $Id: Transcode.pm,v 1.20 2006/08/16 19:34:38 joern Exp $
+# $Id: Transcode.pm,v 1.20.2.2 2007/08/09 21:37:41 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2006 Jrn Reder <joern AT zyn.de>.
@@ -33,6 +33,7 @@ sub build_factory {
     my $context = $self->get_context;
 
     return Gtk2::Ex::FormFactory::VBox->new(
+        $self->get_optimum_screen_size_options("page"),
         object      => "title",
         title       => '[gtk-convert]'.__ "Transcode",
         active_cond => sub {
@@ -910,6 +911,13 @@ sub add_to_cluster {
         return 1;
     }
 
+    if ( not $title->has_target_audio_tracks and $title->is_ogg ) {
+        $self->message_window( message => __
+                "Transcoding without audio in an OGG container isn't ".
+                "supported in cluster mode." );
+        return 1;
+    }
+
     if (   $title->tc_start_frame ne ''
         or $title->tc_end_frame ne '' ) {
         $self->message_window(
